Module: RKSeal::Commands

Defined in:
lib/rkseal/commands/edit.rb,
lib/rkseal/commands/list.rb,
lib/rkseal/commands/view.rb,
lib/rkseal/commands/create.rb,
lib/rkseal/commands/result.rb,
lib/rkseal/commands/validate.rb,
lib/rkseal/commands/reencrypt.rb,
lib/rkseal/commands/edit_local.rb

Defined Under Namespace

Classes: Create, Edit, EditLocal, List, Reencrypt, Result, Validate, View

Instance Attribute Summary collapse

Instance Attribute Details

#deployedBoolean (readonly)

Returns whether the manifest was applied to the cluster (always false for ‘create`).

Returns:

  • (Boolean)

    whether the manifest was applied to the cluster (always false for ‘create`).



20
# File 'lib/rkseal/commands/result.rb', line 20

Result = Data.define(:secret_name, :namespace, :output_path, :deployed)

#namespaceString (readonly)

Returns the namespace it was sealed for.

Returns:

  • (String)

    the namespace it was sealed for.



20
# File 'lib/rkseal/commands/result.rb', line 20

Result = Data.define(:secret_name, :namespace, :output_path, :deployed)

#output_pathString (readonly)

Returns absolute path of the written ‘<name>.yaml`.

Returns:

  • (String)

    absolute path of the written ‘<name>.yaml`.



20
# File 'lib/rkseal/commands/result.rb', line 20

Result = Data.define(:secret_name, :namespace, :output_path, :deployed)

#secret_nameString (readonly)

Returns the Secret name that was sealed.

Returns:

  • (String)

    the Secret name that was sealed.



20
# File 'lib/rkseal/commands/result.rb', line 20

Result = Data.define(:secret_name, :namespace, :output_path, :deployed)