Exception: RKSeal::EditorError

Inherits:
Error
  • Object
show all
Defined in:
lib/rkseal/errors.rb

Overview

‘$EDITOR` is unset/blank, could not be launched, or exited in a way that signals the user aborted the edit.