Exception: RKSeal::InvalidInputError
- Defined in:
- lib/rkseal/errors.rb
Overview
The user’s input is unusable: an empty edit buffer, malformed YAML from the editor, a manifest that is not a valid Kubernetes Secret, an unknown scope, a ‘–from-file` path that does not exist, etc.