Exception: RKSeal::NotFoundError

Inherits:
Error
  • Object
show all
Defined in:
lib/rkseal/errors.rb

Overview

The thing the user asked to operate on does not exist where it must. Notably: ‘edit` was asked for a Secret that is absent from the cluster (the message must point the user at `rkseal create`).