Module: RKSeal::Commands
- Defined in:
- lib/rkseal/commands/edit.rb,
lib/rkseal/commands/list.rb,
lib/rkseal/commands/view.rb,
lib/rkseal/commands/create.rb,
lib/rkseal/commands/result.rb,
lib/rkseal/commands/validate.rb,
lib/rkseal/commands/reencrypt.rb,
lib/rkseal/commands/edit_local.rb
Defined Under Namespace
Classes: Create, Edit, EditLocal, List, Reencrypt, Result, Validate, View
Instance Attribute Summary collapse
-
#deployed ⇒ Boolean
readonly
Whether the manifest was applied to the cluster (always false for ‘create`).
-
#namespace ⇒ String
readonly
The namespace it was sealed for.
-
#output_path ⇒ String
readonly
Absolute path of the written ‘<name>.yaml`.
-
#secret_name ⇒ String
readonly
The Secret name that was sealed.
Instance Attribute Details
#deployed ⇒ Boolean (readonly)
Returns whether the manifest was applied to the cluster (always false for ‘create`).
20 |
# File 'lib/rkseal/commands/result.rb', line 20 Result = Data.define(:secret_name, :namespace, :output_path, :deployed) |
#namespace ⇒ String (readonly)
Returns the namespace it was sealed for.
20 |
# File 'lib/rkseal/commands/result.rb', line 20 Result = Data.define(:secret_name, :namespace, :output_path, :deployed) |
#output_path ⇒ String (readonly)
Returns absolute path of the written ‘<name>.yaml`.
20 |
# File 'lib/rkseal/commands/result.rb', line 20 Result = Data.define(:secret_name, :namespace, :output_path, :deployed) |
#secret_name ⇒ String (readonly)
Returns the Secret name that was sealed.
20 |
# File 'lib/rkseal/commands/result.rb', line 20 Result = Data.define(:secret_name, :namespace, :output_path, :deployed) |